;******************************************************************************
;                                                                             *
; Copyright (C) 2012 Sergio García-Cuevas González.                           *
;                                                                             *
; This program is free software; you can redistribute it and/or modify        *
; it under the terms of the GNU General Public License as published by        *
; the Free Software Foundation; either version 3 of the License, or           *
; (at your option) any later version.                                         *
;                                                                             *
; This program is distributed in the hope that it will be useful,             *
; but WITHOUT ANY WARRANTY; without even the implied warranty of              *
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               *
; GNU General Public License for more details.                                *
;                                                                             *
; You should have received a copy of the GNU General Public License           *
; along with this program.  If not, see <http://www.gnu.org/licenses/>.       *
;                                                                             *
;******************************************************************************

#ifndef CONFIG_INC
#define CONFIG_INC

        list      p=12f629
        #include <p12f629.inc>

; Pin assignment.
left_pin   EQU GP1
right_pin  EQU GP4
motors_pin EQU GP2
light_pin  EQU GP0
horn_pin   EQU GP5
input_pin  EQU GP3

CMCON_cfg EQU b'00000111' ; CMCON configuration.
              ; -----111    CM2:CM0: comparator off.

TRISIO_cfg EQU 1<<input_pin ; TRISIO configuration: only input_pin is input.

OPTION_REG_cfg EQU b'00000111' ; OPTION_REG configuration.
                   ; --0-----    T0CS: use CLKOUT for TMR0.
                   ; ----0---    PSA: prescaler is assigned to TMR0.
                   ; -----111    PS2:PS0: 1:256 prescaler.

IOC_cfg EQU 1<<input_pin ; IOC configuration: enable IOC for input_pin.

INTCON_cfg EQU b'10101000' ; INTCON configuration.
               ; 1-------    GIE: enable interrupts.
               ; -0------    PEIE: disable peripheral interrupts.
               ; --1-----    T0IE: enable T0 interrupts.
               ; ---0----    INTE: disble INT interrupts.
               ; ----1---    GPIE: disable GPIO interrupts.
               ; -----0--    T0IF: clear T0 interrupt flag.
               ; ------0-    INTF: clear INT interrupt flag.
               ; -------0    GPIF: clear GPIO interrupt flag.

; GPIOs for the different actions.
stop_gpio     EQU 0
forward_gpio  EQU 1<<motors_pin|1<<left_pin|1<<right_pin
backward_gpio EQU 1<<motors_pin
left_gpio     EQU 1<<motors_pin|1<<right_pin
right_gpio    EQU 1<<motors_pin|1<<left_pin
horn_gpio     EQU 1<<horn_pin
light_gpio    EQU 1<<light_pin

; Commands.
stop_cmd     EQU 0 ; Stop and wait.
forward_cmd  EQU 1 ; Go forward.
backward_cmd EQU 2 ; Go backward.
left_cmd     EQU 3 ; Turn left.
right_cmd    EQU 4 ; Turn right.
horn_cmd     EQU 5 ; Use the horn.
light_cmd    EQU 6 ; Turn on the light.

; Bookkeeping flags (state file).
applied   EQU 1 ; We have applied the command.
got_cmd   EQU 2 ; We have a stable reading of the command.
seen      EQU 3 ; We have processed the current reading.
motors_on EQU 4 ; The motors are ON with this command.
duty_high EQU 5 ; We are on the high part of the duty-cycle.

; Consecutive equal readings for a stable reading. 
countdown    EQU d'2'

; Number of pulses for each command.
stop_pulses     EQU d'1'  ; Stop and wait.
backward_pulses EQU d'10' ; Go backward.
forward_pulses  EQU d'19' ; Go forward.
left_pulses     EQU d'27' ; Turn left.
right_pulses    EQU d'36' ; Turn right.
horn_pulses     EQU d'45' ; Use the horn.

; Motor duty-cycle durations.
duty_on  EQU d'40'  ; Number of iterations with the motors ON (high part).
duty_off EQU d'255' ; Number of iterations with the motors OFF (low part).

#endif
