/*****************************************************************************
 *                                                                            *
 * Copyright (C) 2012 Sergio García-Cuevas González.                          *
 *                                                                            *
 * This program is free software; you can redistribute it and/or modify       *
 * it under the terms of the GNU General Public License as published by       *
 * the Free Software Foundation; either version 3 of the License, or          *
 * (at your option) any later version.                                        *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.      *
 *                                                                            *
 *****************************************************************************/


/* Ball caster mount for "Placa Buggy 1." */

hole_separation = 2.54;
length = 9 * hole_separation;
inner_span = 17 * hole_separation;
outer_span = 21 * hole_separation;
thickness = 1.5;
height = 6.0;
screw_radius = 1.3;
screw_separation = 15.0;
attachment_separation = 7 * hole_separation;
attachment_radius = 1.0;

union ()
{
  difference ()
  {
    cube (size = [length, inner_span, thickness]);
    union ()
    {
      translate (v = [(length - screw_separation) / 2, inner_span / 2, 0])
      {
        cylinder (r = screw_radius, h = thickness);
      }
      translate (v = [(length + screw_separation) / 2, inner_span / 2, 0])
      {
        cylinder (r = screw_radius, h = thickness);
      }
    }
  }
  cube (size = [length, thickness, height]);
  translate (v = [0, inner_span - thickness, 0])
  {
    cube (size = [length, thickness, height]);
  }
  difference ()
  {
    translate (v = [0, -(outer_span - inner_span) / 2, height - thickness])
    {
      cube (size = [length,
                    (outer_span - inner_span) / 2 + thickness,
                    thickness]);
    }
    union ()
    {
      translate ([(length - attachment_separation) / 2,
                  -(outer_span - inner_span) / 4,
                  height - thickness])
      {
        cylinder (r = attachment_radius, thickness);
      }
      translate ([(length + attachment_separation) / 2,
                  -(outer_span - inner_span) / 4,
                  height  - thickness])
      {
        cylinder (r = attachment_radius, thickness);
      }
    }
  }
  difference ()
  {
    translate (v = [0, inner_span - thickness, height - thickness])
    {
      cube (size = [length,
                    (outer_span - inner_span) / 2 + thickness,
                    thickness]);
    }
    union ()
    {
      translate ([(length - attachment_separation) / 2,
                  inner_span + (outer_span - inner_span) / 4,
                  height - thickness])
      {
        cylinder (r = attachment_radius, thickness);
      }
      translate ([(length + attachment_separation) / 2,
                  inner_span + (outer_span - inner_span) / 4,
                  height  - thickness])
      {
        cylinder (r = attachment_radius, thickness);
      }
    }
  }
}
